#include <algorithm>
#include <iostream>
#include <iomanip>
#include <cassert>
#include <chrono>
#include <random>
#include <string>
#include <vector>
#include <cmath>
#include <queue>
#include <deque>
#include <set>
#include <map>
using namespace std;
#define forn(i, n) for (int i = 0; i < (n); i++)
#define rforn(i, n) for (int i = (n) - 1; i >= 0; i--)
#define all(x) x.begin(), x.end()
#define rall(x) x.rbegin(), x.rend()
#define fastio ios::sync_with_stdio(false), cin.tie(0)
bool space = true, newLine = false, newLineA = false;
template<class T>
istream& operator>>(istream & in, vector<T>&v) {
	for (auto& i : v) in >> i;
	return in;
}
template<class T>
ostream& operator<<(ostream& out, const vector<T>& v) {
	for (const auto& i : v) {
		out << i;
		if (newLine) cout << '\n';
		else if (space) cout << ' ';
	}
	if (newLineA && !newLine) cout << '\n';
	return out;
}
template<class T, class U>
istream& operator>>(istream& in, pair<T, U>& p) {
	in >> p.first >> p.second;
	return in;
}
template<class T, class U>
ostream& operator<<(ostream& out, const pair<T, U>& p) {
	out << p.first << ' ' << p.second;
	return out;
}
// mt19937 rnd(chrono::high_resolution_clock::now().time_since_epoch().count());
mt19937 rnd(1234);
int randnum(int l, int r) {
	return l + rnd() % (r - l + 1);
}

const int zero = 0;
struct node {
	int x, l, r;
	int push;

	node() : l(1e9), r(-1), x(zero), push(zero) {}
	node(int l, int r) : x(zero), l(l), r(r), push(zero) {}
	node(int x, int l, int r) : x(x), l(l), r(r), push(zero) {}

	node operator+(const node& n) const {
		return node(x + n.x, l, n.r);
	}
};

struct segmentTree {
	int n;
	vector<node> t;

	void build(const vector<int>& v) {
		n = 1;
		while (n < v.size()) n *= 2;
		n *= 2;
		t.resize(n);
		for (int i = n / 2; i < n; i++) {
			t[i] = node(i - n / 2 < v.size() ? v[i - n / 2] : zero, i - n / 2, i - n / 2);
		}
		for (int i = n / 2 - 1; i >= 1; i--) {
			t[i] = t[2 * i] + t[2 * i + 1];
		}
	}
	void build(const int& n) {
		build(vector<int>(n, zero));
	}

	segmentTree() : n(0), t(vector<node>()) {}
	segmentTree(int n) {
		build(n);
	}
	segmentTree(const vector<int>& v) {
		build(v);
	}

	void push(int v) {
		t[v].x += (t[v].r - t[v].l + 1) * t[v].push;
		if (t[v].l != t[v].r) {
			t[2 * v].push += t[v].push;
			t[2 * v + 1].push += t[v].push;
		}
		t[v].push = 0;
	}

	node get(int v, int l, int r) {
		push(v);
		if (l <= t[v].l && t[v].r <= r) {
			return t[v];
		}
		if (t[v].r < l || r < t[v].l) {
			return node();
		}
		return get(2 * v, l, r) + get(2 * v + 1, l, r);
	}
	int get(int l, int r) {
		return get(1, l, r).x;
	}

	void update(int v, int l, int r, int x) {
		push(v);
		if (l <= t[v].l && t[v].r <= r) {
			t[v].push = x;
			push(v);
			return;
		}
		if (t[v].r < l || r < t[v].l) {
			return;
		}
		update(2 * v, l, r, x);
		update(2 * v + 1, l, r, x);
		t[v] = t[2 * v] + t[2 * v + 1];
	}
	void update(int l, int r, int x) {
		update(1, l, r, x);
	}
};

struct sparseTable {
	int lg;
	int n;
	vector<int> lg2;
	vector<vector<int>> s;

	void build(const vector<int>& v) {
		lg = 1;
		while ((1 << (lg + 1)) < v.size()) lg++;
		lg++;
		n = v.size();

		lg2.resize(n + 1, 0);
		for (int i = 2; i < lg2.size(); i++) {
			lg2[i] = lg2[i >> 1] + 1;
		}

		s.resize(lg, vector<int>(n));
		s[0] = v;
		for (int i = 1; i < lg; i++) {
			for (int j = 0; j < n - (1 << i) + 1; j++) {
				s[i][j] = min(s[i - 1][j], s[i - 1][j + (1 << (i - 1))]);
			}
		}
	}

	sparseTable() : lg(0), n(0), lg2(vector<int>()), s(vector<vector<int>>()) {}
	sparseTable(const vector<int>& v) {
		build(v);
	}

	int get(int l, int r) {
		int len = lg2[r - l + 1];
		return min(s[len][l], s[len][r - (1 << len) + 1]);
	}
};

int main() {
	fastio;
	int q;
	cin >> q;
	while (q--) {
		int n;
		cin >> n;
		vector<int> v(n);
		cin >> v;

		map<int, vector<int>> d;
		forn(i, n - 1) d[v[i + 1] - v[i]].push_back(i);

		if (d.size() <= 1) {
			cout << "0\n";
			continue;
		}

		if (d.size() > 2) {
			cout << "-1\n";
			continue;
		}

		bool good = true;
		int positive = -1;
		for (auto i : d) {
			if (i.first >= 0) {
				if (positive == -1) positive = i.first;
				else {
					good = false;
					break;
				}
			}
		}
		if (!good) {
			cout << "-1\n";
			continue;
		}

		int m = -1;
		int cur = v[0];
		int mx = v[0];
		forn(i, n) {
			mx = max(mx, v[i]);
			if (m != -1 && mx >= m) {
				good = false;
				break;
			}
			if (cur != v[i]) {
				if (m != -1) {
					good = false;
					break;
				}
				else {
					m = cur - v[i];
					if (m <= 0) {
						good = false;
						break;
					}
					cur %= m;
				}
			}
			cur += positive;
			if (m != -1) cur %= m;
		}
		if (mx >= m) {
			good = false;
		}
		if (!good) {
			cout << "-1\n";
			continue;
		}
		cout << m << ' ' << positive << '\n';
	}
	return 0;
}