#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <unordered_map>
#include <bitset>
#include <array>
#include <chrono>
#include <unordered_set>
#include <queue>
#include <deque>
#include <cmath>
#include <cassert>

using namespace std;

#pragma GCC optimize("unroll-loops")
#pragma GCC target("avx,avx2,sse,sse2,sse3,sse4.1,sse4.2,tune=native")

#define int long long

const int k = 475;
const double eps = 1e-7;
const int inf = 1e18;

int gcd(int a, int b) {
    if (!b) {
        return a;
    }
    return gcd(b, a % b);
}

struct SegTree {
    vector<int> tree;
    vector<pair<int, pair<int, int>>> d;
    
    void init(int n) {
        tree.assign(n * 4, 0);
    }
    
    void build(int i, int l, int r) {
        if (l + 1 == r) {
            tree[i] = 1;
            return;
        }
        int m = (l + r) / 2;
        build(i * 2 + 1, l, m);
        build(i * 2 + 2, m, r);
        tree[i] = tree[i * 2 + 1] + tree[i * 2 + 2];
    }
    
    void decompose(int i, int l, int r, int ql, int qr) {
        if (r <= ql || qr <= l) {
            return;
        }
        if (ql <= l && r <= qr) {
            d.push_back({ i, { l, r } });
            return;
        }
        int m = (l + r) / 2;
        decompose(i * 2 + 1, l, m, ql, qr);
        decompose(i * 2 + 2, m, r, ql, qr);
    }
    
    int nxt(int i, int l, int r) {
        if (l + 1 == r) {
            return l;
        }
        int m = (l + r) / 2;
        if (tree[i * 2 + 1]) {
            return nxt(i * 2 + 1, l, m);
        }
        return nxt(i * 2 + 2, m, r);
    }
    
    void upd(int i, int l, int r, int qi, int val) {
        if (r <= qi || qi < l) {
            return;
        }
        if (l + 1 == r) {
            tree[i] = val;
            return;
        }
        int m = (l + r) / 2;
        upd(i * 2 + 1, l, m, qi, val);
        upd(i * 2 + 2, m, r, qi, val);
        tree[i] = tree[i * 2 + 1] + tree[i * 2 + 2];
    }
    
    int get(int i, int l, int r, int ql, int qr) {
        if (qr <= l || r <= ql) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return tree[i];
        }
        int m = (l + r) / 2;
        return get(i * 2 + 1, l, m, ql, qr) + get(i * 2 + 2, m, r, ql, qr);
    }
};

SegTree st;
SegTree st1;

int nxt(int pos, int n) {
    if (st.get(0, 0, n, pos + 1, n)) {
        st.d.clear();
        st.decompose(0, 0, n, pos + 1, n);
        for (int i = 0; i < st.d.size(); ++i) {
            if (st.tree[st.d[i].first]) {
                return st.nxt(st.d[i].first, st.d[i].second.first, st.d[i].second.second);
            }
        }
    }
    return st.nxt(0, 0, n);
}

int nxt1(int pos, int n) {
    if (st1.get(0, 0, n, pos, n)) {
        st1.d.clear();
        st1.decompose(0, 0, n, pos, n);
        for (int i = 0; i < st1.d.size(); ++i) {
            if (st1.tree[st1.d[i].first]) {
                return st1.nxt(st1.d[i].first, st1.d[i].second.first, st1.d[i].second.second);
            }
        }
    }
    return st1.nxt(0, 0, n);
}

void solve() {
    int n;
    cin >> n;
    vector<int> a(n);
    for (int& i : a) {
        cin >> i;
    }
    st.init(n);
    st1.init(n);
    st.build(0, 0, n);
    for (int i = 0; i < n; ++i) {
        if (gcd(a[i], a[(i + 1) % n]) == 1) {
            st1.upd(0, 0, n, i, 1);
        }
    }
    vector<int> res;
    int pos = n - 1;
    while (true) {
        pos = nxt(pos, n);
        if (st1.tree[0] == 0) {
            break;
        }
        int curr;
        if (st1.get(0, 0, n, pos, n) != 0) {
            curr = nxt1(pos, n);
        } else {
            curr = nxt1(0, n);
        }
        int victim = nxt(curr, n);
        st1.upd(0, 0, n, curr, 0);
        st.upd(0, 0, n, victim, 0);
        st1.upd(0, 0, n, victim, 0);
        res.push_back(victim);
        int nw = nxt(curr, n);
        if (st.get(0, 0, n, nw, nw + 1) && st.get(0, 0, n, curr, curr + 1)) {
            if (gcd(a[nw], a[curr]) == 1) {
                st1.upd(0, 0, n, curr, 1);
            }
        }
        if (st1.tree[0] == 0) {
            break;
        }
        pos = curr;
    }
    cout << res.size() << ' ';
    for (int i : res) {
        cout << i + 1 << ' ';
    }
    cout << '\n';
}

int32_t main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    auto start = chrono::high_resolution_clock().now();
    
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
    
    auto end = chrono::high_resolution_clock().now();
    cerr << "Execution time: " << chrono::duration_cast<chrono::milliseconds>(end - start).count() << "ms";
}
