#include <algorithm>
#include <iostream>
#include <iomanip>
#include <cassert>
#include <chrono>
#include <random>
#include <string>
#include <vector>
#include <cmath>
#include <queue>
#include <deque>
#include <set>
#include <map>
using namespace std;
typedef long long ll;
#define forn(i, n) for (ll i = 0; i < (n); i++)
#define rforn(i, n) for (ll i = (n) - 1; i >= 0; i--)
#define all(x) x.begin(), x.end()
#define rall(x) x.rbegin(), x.rend()
#define fastio ios::sync_with_stdio(false), cin.tie(0)
bool space = true, newLine = false, newLineA = false;
template<class T>
istream& operator>>(istream & in, vector<T>&v) {
	for (auto& i : v) in >> i;
	return in;
}
template<class T>
ostream& operator<<(ostream& out, const vector<T>& v) {
	for (const auto& i : v) {
		out << i;
		if (newLine) cout << '\n';
		else if (space) cout << ' ';
	}
	if (newLineA && !newLine) cout << '\n';
	return out;
}
template<class T, class U>
istream& operator>>(istream& in, pair<T, U>& p) {
	in >> p.first >> p.second;
	return in;
}
template<class T, class U>
ostream& operator<<(ostream& out, const pair<T, U>& p) {
	out << p.first << ' ' << p.second;
	return out;
}
// mt19937 rnd(chrono::high_resolution_clock::now().time_since_epoch().count());
mt19937 rnd(1234);
ll randnum(ll l, ll r) {
	return l + rnd() % (r - l + 1);
}

const ll zero = 0;
struct node {
	ll x;
	ll l, r;
	ll push;

	node() : l(1e9), r(-1), x(-1e18), push(zero) {}
	node(ll l, ll r) : x(zero), l(l), r(r), push(zero) {}
	node(ll x, ll l, ll r) : x(x), l(l), r(r), push(zero) {}

	node operator+(const node& n) const {
		return node(max(x, n.x), l, n.r);
	}
};

struct segmentTree {
	ll n;
	vector<node> t;

	void build(const vector<ll>& v) {
		n = 1;
		while (n < v.size()) n *= 2;
		n *= 2;
		t.resize(n);
		for (ll i = n / 2; i < n; i++) {
			t[i] = node(i - n / 2 < v.size() ? v[i - n / 2] : (ll)-1e18, i - n / 2, i - n / 2);
		}
		for (ll i = n / 2 - 1; i >= 1; i--) {
			t[i] = t[2 * i] + t[2 * i + 1];
		}
	}
	void build(const ll& n) {
		build(vector<ll>(n, zero));
	}

	segmentTree() : n(0), t(vector<node>()) {}
	segmentTree(ll n) {
		build(n);
	}
	segmentTree(const vector<ll>& v) {
		build(v);
	}

	void push(ll v) {
		t[v].x += t[v].push;
		if (t[v].l != t[v].r) {
			t[2 * v].push += t[v].push;
			t[2 * v + 1].push += t[v].push;
		}
		t[v].push = 0;
	}

	node get(ll v, ll l, ll r) {
		push(v);
		if (l <= t[v].l && t[v].r <= r) {
			return t[v];
		}
		if (t[v].r < l || r < t[v].l) {
			return node();
		}
		return get(2 * v, l, r) + get(2 * v + 1, l, r);
	}
	ll get(ll l, ll r) {
		return get(1, l, r).x;
	}

	void update(ll v, ll l, ll r, ll x) {
		push(v);
		if (l <= t[v].l && t[v].r <= r) {
			t[v].push += x;
			push(v);
			return;
		}
		if (t[v].r < l || r < t[v].l) {
			return;
		}
		update(2 * v, l, r, x);
		update(2 * v + 1, l, r, x);
		t[v] = t[2 * v] + t[2 * v + 1];
	}
	void update(ll l, ll r, ll x) {
		update(1, l, r, x);
	}
};

struct sparseTable {
	ll lg;
	ll n;
	vector<ll> lg2;
	vector<vector<ll>> s;

	void build(const vector<ll>& v) {
		lg = 1;
		while ((1 << (lg + 1)) < v.size()) lg++;
		lg++;
		n = v.size();

		lg2.resize(n + 1, 0);
		for (ll i = 2; i < lg2.size(); i++) {
			lg2[i] = lg2[i >> 1] + 1;
		}

		s.resize(lg, vector<ll>(n));
		s[0] = v;
		for (ll i = 1; i < lg; i++) {
			for (ll j = 0; j < n - (1 << i) + 1; j++) {
				s[i][j] = min(s[i - 1][j], s[i - 1][j + (1 << (i - 1))]);
			}
		}
	}

	sparseTable() : lg(0), n(0), lg2(vector<ll>()), s(vector<vector<ll>>()) {}
	sparseTable(const vector<ll>& v) {
		build(v);
	}

	ll get(ll l, ll r) {
		ll len = lg2[r - l + 1];
		return min(s[len][l], s[len][r - (1 << len) + 1]);
	}
};

vector<ll> slow(vector<ll> h, vector<ll> b) {
	ll n = h.size();

	vector<ll> dp(n, -1e18);

	forn(i, n) {
		ll himn = i;
		for (ll j = i; j >= 0; j--) {
			if (h[j] < h[himn]) himn = j;
			dp[i] = max(dp[i], (j == 0 ? 0 : dp[j - 1]) + b[himn]);
		}
	}
	return dp;
}

vector<ll> fast(vector<ll> h, vector<ll> b) {
	ll n = h.size();

	vector<ll> dp(n);
	segmentTree st(n);

	vector<ll> pos;

	ll himn = 0;
	forn(i, n) {
		if (h[i] < h[himn]) himn = i;

		ll k = i - 1;
		while (pos.size() && h[pos.back()] > h[i]) {
			ll old = pos.back();
			pos.pop_back();

			st.update(old, k, b[i] - b[k + 1]);
			k = old - 1;
		}

		st.update(pos.empty() ? 0 : pos.back(), k, b[i] - b[k + 1]);

		pos.push_back(i);

		dp[i] = max(st.get(0, i - 1), b[himn]);

		if (i != n - 1) st.update(i, i, dp[i] + b[i + 1]);
	}

	return dp;
}

void test() {
	const ll n = 10;
	while (true) {
		vector<ll> h(n);
		vector<ll> b(n);
		forn(i, n) {
			h[i] = i;
			b[i] = randnum(-1e9, 1e9);
		}
		shuffle(all(h), rnd);
		if (slow(h, b) != fast(h, b)) {
			cout << h << '\n' << b << "\n\n";
			slow(h, b);
			fast(h, b);
		}
	}
}

signed main() {
	fastio;
	// test();
	ll n;
	cin >> n;
	vector<ll> h(n);
	vector<ll> b(n);
	cin >> h >> b;
	for (auto& i : h) i--;

	cout << fast(h, b).back();
	return 0;
}