#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

typedef long long ll;

const ll INF = 1e18;

struct segment_tree {
  int n;
  vector <ll> t;
  segment_tree(int _n) {
    n = _n;
    t.resize(n << 2, -INF);
  }
  void upd(int v, int tl, int tr, int pos, ll val) {
    if (tl == tr) {
      t[v] = val;
      return;
    }
    int tm = (tl + tr) / 2;
    if (pos <= tm)
      upd(v * 2, tl, tm, pos, val);
    else
      upd(v * 2 + 1, tm + 1, tr, pos, val);
    t[v] = max(t[v * 2], t[v * 2 + 1]);
  }
  ll get(int v, int tl, int tr, int l, int r) {
    if (l > r)
      return -INF;
    if (l == tl && r == tr)
      return t[v];
    int tm = (tl + tr) / 2;
    ll x = get(v * 2, tl, tm, l, min(r, tm));
    ll y = get(v * 2 + 1, tm + 1, tr, max(l, tm + 1), r);
    return max(x, y);
  }
  void upd(int pos, ll val) {
    upd(1, 0, n - 1, pos, val);
  }
  ll get(int l, int r) {
    return get(1, 0, n - 1, l, r);
  }
};

struct help_tree {
  int n;
  vector <int> t;
  help_tree(int _n) {
    n = _n;
    t.resize(n << 2);
  }
  void build(int v, int tl, int tr, vector <ll> &a) {
    if (tl == tr) {
      t[v] = a[tl];
      return;
    }
    int tm = (tl + tr) / 2;
    build(v * 2, tl, tm, a);
    build(v * 2 + 1, tm + 1, tr, a);
    t[v] = min(t[v * 2], t[v * 2 + 1]);
  }
  int get(int v, int tl, int tr, int pos, int val) {
    if (t[v] >= val)
      return -1;
    if (tl >= pos)
      return -1;
    if (tl == tr)
      return tl;
    int tm = (tl + tr) / 2;
    int res = get(v * 2 + 1, tm + 1, tr, pos, val);
    if (res == -1)
      res = get(v * 2, tl, tm, pos, val);
    return res;
  }
  void build(vector <ll> &a) {
    build(1, 0, n - 1, a);
  }
  int get(int pos, int val) {
    return get(1, 0, n - 1, pos, val);
  }
};

int main() {
  ios::sync_with_stdio(false);
  cin.tie(0);
  int n;
  cin >> n;
  vector <ll> a(n), b(n);
  for (int i = 0; i < n; i++) {
    cin >> a[i];
    a[i]--;
  }
  for (int i = 0; i < n; i++)
    cin >> b[i];
  vector <ll> stupid(n), mi(n), ma(n);
  stupid[0] = b[0];
  mi[0] = a[0];
  for (int i = 1; i < n; i++) {
    if (a[i] < mi[i - 1]) {
      stupid[i] = b[i];
    } else {
      stupid[i] = stupid[i - 1];
    }
    mi[i] = min(a[i], mi[i - 1]);
  }
  segment_tree st(n); // ответ на задачу; st[i] = ответ для префикса i
  help_tree ht(n);
  ht.build(a);
  for (int i = 0; i < n; i++) {
    ll ans1 = stupid[i]; // если просто взять всё как один отрезок
    if (i == 0) {
      st.upd(i, stupid[i]);
      continue;
    }
    if (mi[i] == a[i]) {
      ll ans2 = st.get(0, i - 1);
      st.upd(i, max(stupid[i], ans2 + b[i]));
      continue;
    }
    int x = ht.get(i, a[i]); // первый элемент, меньше данного
    st.upd(i, max({stupid[i], st.get(x, x), st.get(x, i - 1) + b[i]}));
  }
  cout << st.get(n - 1, n - 1);
  return 0;
}
