#include <iostream>
#include <vector>
#include <algorithm>
#include <stack>
#define int long long 
using namespace std;

const int inf = 1e18;

struct Segtree_max {
	vector<int> tree, add;
	int n;

	Segtree_max(int n) : n(n), tree(4 * n), add(4 * n) { }

	void push(int v, int tl, int tr) {
		if (add[v] != 0) {
			tree[v] += add[v];
			if (tl != tr) {
				add[v * 2] += add[v];
				add[v * 2 + 1] += add[v];
			}
			add[v] = 0;
		}
	}

	void upd(int v, int tl, int tr, int l, int r, int x) {
		push(v, tl, tr);
		if (l > r) return;
		if (tl == l && tr == r) {
			add[v] += x;
			push(v, tl, tr);
		}
		else {
			int tm = (tl + tr) >> 1;
			upd(v * 2, tl, tm, l, min(r, tm), x);
			upd(v * 2 + 1, tm + 1, tr, max(l, tm + 1), r, x);
			tree[v] = max(tree[v * 2], tree[v * 2 + 1]);
		}
	}

	void upd(int l, int r, int x) {
		upd(1, 0, n - 1, l, r, x);
	}

	int get(int v, int tl, int tr, int l, int r) {
		if (l > r) return -inf;
		if (tl == l && tr == r) return tree[v];
		int tm = (tl + tr) >> 1;
		return max(get(v * 2, tl, tm, l, min(r, tm)),
			get(v * 2 + 1, tm + 1, tr, max(l, tm + 1), r));
	}

	int get(int l, int r) {
		return get(1, 0, n - 1, l, r);
	}
};

vector<int> h, d;
struct Segtree_min {
	vector<int> tree;
	int n;
	
	void build(int v, int tl, int tr) {
		if (tl == tr) tree[v] = tl;
		else {
			int tm = (tl + tr) >> 1;
			build(v * 2, tl, tm);
			build(v * 2 + 1, tm + 1, tr);

			if (h[tree[v * 2]] < h[tree[v * 2 + 1]])
				tree[v] = tree[v * 2];
			else
				tree[v] = tree[v * 2 + 1];
		}
	}

	Segtree_min(int n) : n(n), tree(4 * n) {
		build(1, 0, n - 1);
	}

	int get(int v, int tl, int tr, int l, int r) {
		if (l > r) return 0;
		if (tl == l && tr == r)
			return tree[v];
		int tm = (tl + tr) >> 1;
		int r1 = get(v * 2, tl, tm, l, min(r, tm));
		int r2 = get(v * 2 + 1, tm + 1, tr, max(l, tm + 1), r);

		if (h[r1] < h[r2])
			return r1;
		else
			return r2;
	}

	int get(int l, int r) {
		return get(1, 0, n - 1, l, r);
	}
};

signed main() {
	ios::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);

	int n;
	cin >> n;

	h.resize(n + 1);
	d.resize(n + 1);
	for (int i = 1; i <= n; ++i)
		cin >> h[i];
	for (int i = 1; i <= n; ++i)
		cin >> d[i];

	h[0] = inf;
	Segtree_min stm(n + 1);
	Segtree_max stx(n + 1);

	vector<int> dp(n + 1);
	dp[0] = 0;
	stack<pair<pair<int, int>, int>> mns;
	for (int i = 1; i <= n; ++i) {
		int left = 1, right = i;
		while (right > left) {
			int mid = (left + right) >> 1;
			if (h[stm.get(mid, right)] >= h[i]) right = mid;
			else left = mid + 1;
		}

		//cout << left << '\n';

		stx.upd(i, i, dp[i - 1] + d[i]);
		while (!mns.empty() && mns.top().first.second >= left) {
			if (mns.top().first.first >= left) {
				stx.upd(mns.top().first.first, mns.top().first.second, -mns.top().second);
				mns.pop();
			}
			else {
				stx.upd(left, mns.top().first.second, -mns.top().second);
				mns.top().first.second = left - 1;
			}
		}
		stx.upd(left, i - 1, d[i]);

		dp[i] = stx.get(1, i);
		mns.push({ {left, i}, d[i] });
	}

	cout << dp[n] << '\n';
}